mkTab<-function(G,short=TRUE)
{options(stringsAsFactors=TRUE)
  ids<-sapply(G,function(x) x$id)
  class<-sapply(G,function(x) x$class)
  trend<-sapply(G,function(x) x$trend)
  done<-sapply(G,function(x) x$done)
  changes<-sapply(G,function(x) x$changes)
  SSEi<-sapply(G,function(x) x$SSE$initial)
  SSEf<-sapply(G,function(x) x$SSE$final)
  AIC<-sapply(G,function(x) x$AIC$final)
  delAIC=AIC-min(AIC)
  P=exp(-delAIC)
  P=P/sum(P)
  mat=t(sapply(G,function(x) x$params[,"final"]))
  colnames(mat)<-row.names(G[[1]]$params)
  tab=data.frame(id=ids,class=class,trend=trend,done=done,changes=changes,SSEi=SSEi,SSEf=SSEf,mat)
  if (short) tab=data.frame(id=ids,SSEi=SSEi,SSEf=SSEf,AIC,P,mat)
  row.names(tab)<-1:dim(tab)[1]
  tab
}

placeMtext<-function(temp,ln,col="black"){
 x=as.integer(temp[1])
mtext(bquote(i[1]==.(x)),adj=0.12, outer=TRUE,line=ln,cex.main=0.9,col=col)
x=as.integer(temp[2])
mtext(bquote(i[2]==.(x)),adj=0.18, outer=TRUE,line=ln,cex.main=0.9,col=col)
x=as.integer(temp[3])
mtext(bquote(i[3]==.(x)),adj=0.26, outer=TRUE,line=ln,cex.main=0.9,col=col)
x=temp[4]
mtext(bquote(k[0]==.(x)),adj=0.43, outer=TRUE,line=ln,cex.main=0.9,col=col)
x=temp[8]
mtext(bquote(K[0]==.(x)),adj=0.59, outer=TRUE,line=ln,cex.main=0.9,col=col)
x=temp[9]
mtext(bquote(K[1]==.(x)),adj=0.71, outer=TRUE,line=ln,cex.main=0.9,col=col)
x=temp[10]
mtext(bquote(K[2]==.(x)),adj=0.83, outer=TRUE,line=ln,cex.main=0.9,col=col)
x=temp[11]
mtext(bquote(K[3]==.(x)),adj=0.95, outer=TRUE,line=ln,cex.main=0.9,col=col)
}


newFig2<-function(sG,kill=FALSE){
  library(plotrix)
  graphics.off();
  windows(width = 9, height = 4,restoreConsole = TRUE,ypos=0) 
  par(mfcol=c(1,1),mar=c(4.2,4,0,1)+.1,oma=c(0,0,4,1))
  g=sG[[1]]
  g2=sG[[20]]
  with(g$dk,gap.plot(XT,k,gap=c(3400,9950),xtics=c(0,1000,2000,3000),
          gap.axis="x",ylim=c(.1,.3),xlim=c(0,3500),
          ylab="CDP Reductase Activity (1/sec)",xlab=expression("[ATP] ("*mu*"M)")))
  axis(1,at=3450,label="10000")
  with(g$pdk,lines(XT,Ek))
  with(g2$pdk,lines(XT,Ek,col="blue"))
  mtext(paste(g$id," (AIC=",signif(g$AIC$final,3),", SSE=",format(g$SSE$final,digits=3),
          ")",sep=""),outer=TRUE,line=2.7,cex.main=1.1,col="black",adj=0.25)
  mtext(paste(g2$id," (AIC=",signif(g2$AIC$final,3),", SSE=",format(g2$SSE$final,digits=3),
          ")",sep=""),outer=TRUE,line=2.7,cex.main=1.1,col="blue",adj=.75)
  if (g$params["p","final"]==1)
      temp=g$params[-dim(g$params)[1],] else temp=g$params 
#    title(paste(row.names(temp),"=",format(temp[,"final"],digits=2,trim=T,
#                nsmall=0,scientific=FALSE),sep="",collapse=";  "), outer=TRUE,line=.7,cex.main=0.95)
    temp=format(temp[,"final"],digits=2,trim=T,nsmall=0,scientific=FALSE)
    placeMtext(temp,ln=1.5)
    if (g2$params["p","final"]==1)
      temp=g2$params[-dim(g2$params)[1],] else temp=g2$params 
    temp=format(temp[,"final"],digits=2,trim=T,nsmall=0,scientific=FALSE)
    print(temp)
    placeMtext(temp,ln=.5,col="blue")
  }




plotg<-function(g,kill=FALSE,mass=FALSE){
  library(plotrix)
  if (kill) graphics.off();
  if (.Platform$OS.type=="windows") 
    windows(width = 9, height = ifelse(mass,8,4),restoreConsole = TRUE,ypos=0) else X11(width=10,height=ifelse(mass,8,4))
  par(mfcol=c(ifelse(mass,2,1),1),mar=c(4.2,4,0,1)+.1,oma=c(0,0,3,1))
  with(g$dk,gap.plot(XT,k,gap=c(3400,9950),xtics=c(0,1000,2000,3000),
          gap.axis="x",ylim=c(.1,.3),xlim=c(0,3500),ylab="CDP Reductase Activity (1/sec)",xlab="[ATP] in uM"))
#  mtext(side=3,line=-1,g$class)
  axis(1,at=3450,label="10000")
  with(g$pdk,lines(XT,Ek))
  title(paste(g$id," (AIC=",signif(g$AIC$final,3),", SSE=",format(g$SSE$final,digits=3),
          ")",sep=""),outer=TRUE,line=1.7,cex.main=1.2)
  if (mass)  { # mass data
    with(g$dm,plot(XT,m,ylim=c(90,540),xlim=c(0,3300),ylab="Average Mass",xlab="[ATP] in uM"))
    with(g$pdm,lines(XT,Em))
    text(200,500,paste("SSE=",format(g$MSSE,digits=3)))
    title(paste(row.names(g$params),"=",format(g$params[,"final"],digits=2,trim=T,
                nsmall=0,scientific=FALSE),sep="",collapse=";  "), outer=TRUE,line=.7,cex.main=0.8)
  } else {
    if (g$params["p","final"]==1)
      temp=g$params[-dim(g$params)[1],] else temp=g$params 
    title(paste(row.names(temp),"=",format(temp[,"final"],digits=2,trim=T,
                nsmall=0,scientific=FALSE),sep="",collapse=";  "), outer=TRUE,line=.7,cex.main=0.95)
  }
  
#  title(paste(row.names(g$params),"=",format(g$params[,"final"],digits=2,trim=T,
}

histG<-function(G,mass=FALSE) {
  windows(width = 10, height = 4)
  par(oma=c(0,0,0,0),mar=c(4.2,4,1,1))
  H=sapply(G,function(x) x$params["i3","final"]>12)
  if (!mass) SSE=sapply(G,function(x) x$SSE$final) else
    SSE=sapply(G,function(x) x$MSSE)
  SSE1=SSE[H]
  SSE2=SSE[!H]
  t.test(SSE1,SSE2)
  wilcox.test(SSE1,SSE2)
  if (!mass) {
    h1=hist(SSE1)
    h2=hist(SSE2)  
  }         else {
    h1=hist(SSE1,breaks=c(0,15e3,seq(25e3,350e3,50e3)))
    h2=hist(SSE2,breaks=c(0,15e3,seq(25e3,350e3,50e3)))
  }
  plot(h1$mids,h1$density,type="l",lty=1,xlab="SSE",ylab="Probability Density",ylim=c(0,ifelse(mass,1.2e-5,320)))
  lines(h2$mids,h2$density,lty=2)
  abline(v=median(SSE1),lty=1)
  abline(v=median(SSE2),lty=2)
  legend("topright",legend=c("h-site models","no h-site models"),lty=1:2,bty="n")
}


plotG<-function(G){
  library(PolynomF)
  library(plotrix)
  if (!is.null(dev.list())) for (i in 2:max(dev.list())) dev.off(i);
  windows(width = 8, height = 8,restoreConsole = TRUE,ypos=0)
  par(mfrow=c(2,2),mar=c(4.2,4,2,1)+.1,cex.axis=0.9) #,oma=c(0,0,3,1))
  SSE=sapply(G,function(x) x$SSE$final)
  hist(SSE,breaks=50)
  (intvf=cut(SSE,breaks=c(0,2*min(SSE),.008,1))) #,labels=paste("G",1:5,sep="")))
  for (i in levels(intvf)) {
    with(G[[1]]$dk,gap.plot(XT,k,gap=c(3400,9950),xtics=c(0,1000,2000,3000),
            gap.axis="x",ylim=c(.1,.3),xlim=c(0,3500),ylab="CDP Reductase Activity (1/sec)",xlab="[ATP] in uM"))
    axis(1,at=3450,label="1e4")
    title(paste("SSE in",i),line=0.4,cex.main=1)
    for (pg in G[intvf==i]) {
      with(pg$pdk,lines(XT,Ek))
#    with(pg$d,gap.plot(XT,k,gap=c(3300,9900),xlim=c(0,3500),add=TRUE))
    }
    with(G[[1]]$dk,points(XT,k,pch="X",col="red",cex=2))  # this works just as well  (can't get the last point up in big red)
#with(G[[1]]$d,gap.plot(XT,k,gap=c(3300,9900),xlim=c(0,3500),type="p",pch="X",col="red",cex=2,add=TRUE))
    text(1500,0.1,paste("Number of models =",sum(intvf==i)))
  }
  windows(width = 5, height = 5,restoreConsole = TRUE,ypos=0)
  par(mfrow=c(1,1),mar=c(4.2,4,2,1)+.1) #,oma=c(0,0,3,1))
  with(G[[1]]$dk,gap.plot(XT,k,gap=c(3400,9950),xtics=c(0,1000,2000,3000),
          gap.axis="x",ylim=c(.1,.3),xlim=c(0,3500),ylab="CDP Reductase Activity (1/sec)",xlab="[ATP] in uM"))
  axis(1,at=3450,label="1e4")
  #  with(G[[1]]$d,plot(XT,k,ylim=c(.1,.3),ylab="CDP Reductase Activity (1/sec)",xlab="[ATP] in uM"))
  title("Top 4 Models",line=0.4,cex.main=1)
  sG=sortG(G)
  for (i in 1:4) with(sG[[i]]$pdk,lines(XT,Ek,lty=i))
  legend(1400,0.17,legend=sapply(sG[1:4],function(x) x$id),lty=1:4,bty="n")
  par(cex.axis=1)
}

reportg<-function(g) {
  if (g$hess) {
    tmp=format(cbind(g$params[g$params$opt,"final",drop=F],g$CI),digits=2,trim=T,scientific=FALSE) 
    tmp=transform(tmp,Wald.95.CI=mapply(paste,"(",lower,", ",upper,")",sep=""))
    names(tmp)[1]<-c("Estimate")
    g$report=subset(tmp,select=c("Estimate","Wald.95.CI"))
  }
  g
}


#
#mkTabS<-function(G)
#{options(stringsAsFactors=FALSE,digits=3,scipen=4)
#  (tab=data.frame(id="XX",cls="",grp="",done=0,chgs=0,p=rep(0,6),SSEi=0,SSEf=0,AIC=0, 
#            i1=0,i2=0,i3=0,#sig=0,AICc=0,AIC=0,AICchk=0,
#            k0=0,k1=0,k2=0,k3=0,
#            K0=0,K1=0,K2=0,K3=0
#        ))
#  for (i in 1:length(G)) {
#    SSEf=G[[i]]$SSE$final
#    SSEi=G[[i]]$SSE$initial
#    AICc=signif(G[[i]]$AIC$final,3) 
#    p=sum(G[[i]]$params[,"opt"])
#    SSEf=format(SSEf,digits=3)
#    SSEi=format(SSEi,digits=3)
#    vals=c(G[[i]]$params[1:3,"final"], format(G[[i]]$params[4:11,"final"],digits=2,trim=T,scientific=FALSE))
#    names(vals)<-row.names(G[[i]]$params)
#    tmp=c(id=G[[i]]$id,cls=G[[i]]$class,grp=G[[i]]$trend,done=G[[i]]$done,chgs=G[[i]]$changes,
#        p=p,SSEi=SSEi,SSEf=SSEf,AIC=AICc,vals)
#    if (length(which(tab$id!="XX"))==0) jj=1 else jj=max(which(tab$id!="XX"))+1
#    tab[jj,names(tmp)]=tmp
#  }
##  tab=data.frame(id=tab$id,lapply(tab[,3:dim(tab)[2]],as.numeric))  # keep tables just for looking at (terminal outputs)
#  #  row.names(tab)<-tab$id
#  tab
#}

